==> dokuwiki-2011.05.25a.tgz: dokuwiki/inc/lang/ku/lang.php <==
<?php
/**
 * kurdish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @translator Erdal Ronahî <erdal.ronahi@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Vê rûpelê biguherîne';
$lang['btn_source'] = 'Çavkaniya rûpelê nîşan bide';
$lang['btn_show']   = 'Rûpelê nîşan bide';
$lang['btn_create'] = 'Vê rûpelê biafirîne';
$lang['btn_search'] = 'Lêbigere';
$lang['btn_save']   = 'Tomar bike';
$lang['btn_preview']= 'Pêşdîtin';
$lang['btn_top']    = 'Biçe ser';
$lang['btn_newer']  = '<< nûtir';
$lang['btn_older']  = 'kevntir >>';
$lang['btn_revs']   = 'Revîziyonên kevn';
$lang['btn_recent'] = 'Guherandinên dawî';
$lang['btn_upload'] = 'Bar bike';
$lang['btn_cancel'] = 'Betal';
$lang['btn_index']  = 'Îndeks';
$lang['btn_secedit']= 'Biguherîne';
$lang['btn_login']  = 'Têkeve';
$lang['btn_logout'] = 'Derkeve';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Rojanekirin';
$lang['btn_delete'] = 'Jê bibe';
$lang['btn_back']   = 'Paş';
$lang['btn_backlink']    = "Girêdanên paş";
$lang['btn_backtomedia'] = 'Back to Mediafile Selection';
$lang['btn_subscribe']   = 'Subscribe Changes';
$lang['btn_unsubscribe'] = 'Unsubscribe Changes';
$lang['btn_register'] = 'Register';

$lang['loggedinas'] = 'Logged in as';
$lang['user']       = 'Username';
$lang['pass']       = 'Password';
$lang['passchk']    = 'once again';
$lang['remember']   = 'Remember me';
$lang['fullname']   = 'Full name';
$lang['email']      = 'E-Mail';
$lang['badlogin']   = 'Sorry, username or password was wrong.';

$lang['regmissing'] = 'Sorry, you must fill in all fields.';
$lang['reguexists'] = 'Sorry, a user with this login already exists.';
$lang['regsuccess'] = 'The user has been created and the password was sent by email.';
$lang['regsuccess2']= 'The user has been created.';
$lang['regmailfail']= 'Looks like there was an error on sending the password mail. Please contact the admin!';
$lang['regbadmail'] = 'The given email address looks invalid - if you think this is an error, contact the admin';
$lang['regbadpass'] = 'The two given passwords are not identically, please try again.';
$lang['regpwmail']  = 'Your DokuWiki password';
$lang['reghere']    = 'You don\'t have an account yet? Just get one';

$lang['txt_upload']   = 'Select file to upload';
$lang['txt_filename'] = 'Enter wikiname (optional)';
$lang['txt_overwrt']  = 'Overwrite existing file';
$lang['lockedby']     = 'Currently locked by';
$lang['lockexpire']   = 'Lock expires at';
$lang['willexpire']   = 'Your lock for editing this page is about to expire in a minute.\nTo avoid conflicts use the preview button to reset the locktimer.';

$lang['js']['notsavedyet'] = "Unsaved changes will be lost.\nReally continue?";

$lang['rssfailed']   = 'An error occured while fetching this feed: ';
$lang['nothingfound']= 'Tiştek nehat dîtin.';

$lang['mediaselect'] = 'Mediafile Selection';
$lang['fileupload']  = 'Mediafile Upload';
$lang['uploadsucc']  = 'Upload successful';
$lang['uploadfail']  = 'Upload failed. Maybe wrong permissions?';
$lang['uploadwrong'] = 'Upload denied. This file extension is forbidden!';
$lang['uploadexist'] = 'File already exists. Nothing done.';
$lang['deletesucc']  = 'The file "%s" has been deleted.';
$lang['deletefail']  = '"%s" couldn\'t be deleted - check permissions.';
$lang['mediainuse']  = 'The file "%s" hasn\'t been deleted - it is still in use.';
$lang['namespaces']  = 'Namespace';
$lang['mediafiles']  = 'Available files in';

$lang['reference']   = 'Referansa';
$lang['ref_inuse']   = 'The file can\'t be deleted, because it\'s still used by the following pages:';
$lang['ref_hidden']  = 'Some references  are on pages you don\'t have permission to read';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Matching pagenames';
$lang['toc']        = 'Tabloya Navêrokê';
$lang['current']    = 'current';
$lang['yours']      = 'Your Version';
$lang['diff']       = 'show differences to current version';
$lang['line']       = 'Rêz';
$lang['breadcrumb'] = 'Şop';
$lang['lastmod']    = 'Guherandina dawî';
$lang['by']         = 'by';
$lang['deleted']    = 'hat jê birin';
$lang['created']    = 'hat afirandin';
$lang['restored']   = 'old revision restored';
$lang['summary']    = 'Kurteya guhartinê';

$lang['mail_newpage'] = 'page added:';
$lang['mail_changed'] = 'page changed:';

$lang['js']['nosmblinks'] = "Linking to Windows shares only works in Microsoft Internet Explorer.\nYou still can copy and paste the link.";

$lang['qb_bold']    = 'Bold Text';
$lang['qb_italic']  = 'Italic Text';
$lang['qb_underl']  = 'Underlined Text';
$lang['qb_code']    = 'Code Text';
$lang['qb_strike']  = 'Strike-through Text';
$lang['qb_h1']      = 'Level 1 Headline';
$lang['qb_h2']      = 'Level 2 Headline';
$lang['qb_h3']      = 'Level 3 Headline';
$lang['qb_h4']      = 'Level 4 Headline';
$lang['qb_h5']      = 'Level 5 Headline';
$lang['qb_link']    = 'Internal Link';
$lang['qb_extlink'] = 'External Link';
$lang['qb_hr']      = 'Horizontal Rule';
$lang['qb_ol']      = 'Ordered List Item';
$lang['qb_ul']      = 'Unordered List Item';
$lang['qb_media']   = 'Add Images and other files';
$lang['qb_sig']     = 'Insert Signature';

$lang['js']['del_confirm']= 'Delete this entry?';

$lang['admin_acl']  = 'Access Control List Management...';
$lang['admin_register']= 'Add new user...';

$lang['acl_group']  = 'Group';
$lang['acl_user']   = 'User';
$lang['acl_perms']  = 'Permissions for';
$lang['page']       = 'Rûpel';
$lang['namespace']  = 'Namespace';

$lang['acl_perm1']  = 'Bixwîne';
$lang['acl_perm2']  = 'Biguherîne';
$lang['acl_perm4']  = 'Biafirîne';
$lang['acl_perm8']  = 'Upload';
$lang['acl_perm16'] = 'Jê bibe';
$lang['acl_new']    = 'Add new Entry';

$lang['metaedit']    = 'Edit Metadata';
$lang['metasaveerr'] = 'Writing metadata failed';
$lang['metasaveok']  = 'Metadata saved';
$lang['img_backto']  = 'Back to';
$lang['img_title']   = 'Title';
$lang['img_caption'] = 'Caption';
$lang['img_date']    = 'Date';
$lang['img_fname']   = 'Filename';
$lang['img_fsize']   = 'Size';
$lang['img_artist']  = 'Photographer';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Format';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Keywords';

$lang['subscribe_success']  = 'Added %s to subscription list for %s';
$lang['subscribe_error']    = 'Error adding %s to subscription list for %s';
$lang['subscribe_noaddress']= 'There is no address associated with your login, you cannot be added to the subscription list';
$lang['unsubscribe_success']= 'Removed %s from subscription list for %s';
$lang['unsubscribe_error']  = 'Error removing %s from subscription list for %s';

//Setup VIM: ex: et ts=2 :

==> dokuwiki-2012.01.25.tgz: dokuwiki/inc/lang/ku/lang.php <==
<?php
/**
 * kurdish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @translator Erdal Ronahî <erdal.ronahi@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Vê rûpelê biguherîne';
$lang['btn_source'] = 'Çavkaniya rûpelê nîşan bide';
$lang['btn_show']   = 'Rûpelê nîşan bide';
$lang['btn_create'] = 'Vê rûpelê biafirîne';
$lang['btn_search'] = 'Lêbigere';
$lang['btn_save']   = 'Tomar bike';
$lang['btn_preview']= 'Pêşdîtin';
$lang['btn_top']    = 'Biçe ser';
$lang['btn_newer']  = '<< nûtir';
$lang['btn_older']  = 'kevntir >>';
$lang['btn_revs']   = 'Revîziyonên kevn';
$lang['btn_recent'] = 'Guherandinên dawî';
$lang['btn_upload'] = 'Bar bike';
$lang['btn_cancel'] = 'Betal';
$lang['btn_index']  = 'Îndeks';
$lang['btn_secedit']= 'Biguherîne';
$lang['btn_login']  = 'Têkeve';
$lang['btn_logout'] = 'Derkeve';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Rojanekirin';
$lang['btn_delete'] = 'Jê bibe';
$lang['btn_back']   = 'Paş';
$lang['btn_backlink']    = "Girêdanên paş";
$lang['btn_backtomedia'] = 'Back to Mediafile Selection';
$lang['btn_subscribe']   = 'Subscribe Changes';
$lang['btn_unsubscribe'] = 'Unsubscribe Changes';
$lang['btn_register'] = 'Register';

$lang['loggedinas'] = 'Logged in as';
$lang['user']       = 'Username';
$lang['pass']       = 'Password';
$lang['passchk']    = 'once again';
$lang['remember']   = 'Remember me';
$lang['fullname']   = 'Full name';
$lang['email']      = 'E-Mail';
$lang['badlogin']   = 'Sorry, username or password was wrong.';

$lang['regmissing'] = 'Sorry, you must fill in all fields.';
$lang['reguexists'] = 'Sorry, a user with this login already exists.';
$lang['regsuccess'] = 'The user has been created and the password was sent by email.';
$lang['regsuccess2']= 'The user has been created.';
$lang['regmailfail']= 'Looks like there was an error on sending the password mail. Please contact the admin!';
$lang['regbadmail'] = 'The given email address looks invalid - if you think this is an error, contact the admin';
$lang['regbadpass'] = 'The two given passwords are not identically, please try again.';
$lang['regpwmail']  = 'Your DokuWiki password';
$lang['reghere']    = 'You don\'t have an account yet? Just get one';

$lang['txt_upload']   = 'Select file to upload';
$lang['txt_filename'] = 'Enter wikiname (optional)';
$lang['txt_overwrt']  = 'Overwrite existing file';
$lang['lockedby']     = 'Currently locked by';
$lang['lockexpire']   = 'Lock expires at';
$lang['js']['willexpire']   = 'Your lock for editing this page is about to expire in a minute.\nTo avoid conflicts use the preview button to reset the locktimer.';

$lang['js']['notsavedyet'] = "Unsaved changes will be lost.\nReally continue?";

$lang['rssfailed']   = 'An error occured while fetching this feed: ';
$lang['nothingfound']= 'Tiştek nehat dîtin.';

$lang['mediaselect'] = 'Mediafile Selection';
$lang['fileupload']  = 'Mediafile Upload';
$lang['uploadsucc']  = 'Upload successful';
$lang['uploadfail']  = 'Upload failed. Maybe wrong permissions?';
$lang['uploadwrong'] = 'Upload denied. This file extension is forbidden!';
$lang['uploadexist'] = 'File already exists. Nothing done.';
$lang['deletesucc']  = 'The file "%s" has been deleted.';
$lang['deletefail']  = '"%s" couldn\'t be deleted - check permissions.';
$lang['mediainuse']  = 'The file "%s" hasn\'t been deleted - it is still in use.';
$lang['namespaces']  = 'Namespace';
$lang['mediafiles']  = 'Available files in';

$lang['reference']   = 'Referansa';
$lang['ref_inuse']   = 'The file can\'t be deleted, because it\'s still used by the following pages:';
$lang['ref_hidden']  = 'Some references  are on pages you don\'t have permission to read';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Matching pagenames';
$lang['toc']        = 'Tabloya Navêrokê';
$lang['current']    = 'current';
$lang['yours']      = 'Your Version';
$lang['diff']       = 'show differences to current version';
$lang['line']       = 'Rêz';
$lang['breadcrumb'] = 'Şop';
$lang['lastmod']    = 'Guherandina dawî';
$lang['by']         = 'by';
$lang['deleted']    = 'hat jê birin';
$lang['created']    = 'hat afirandin';
$lang['restored']   = 'old revision restored';
$lang['summary']    = 'Kurteya guhartinê';

$lang['mail_newpage'] = 'page added:';
$lang['mail_changed'] = 'page changed:';

$lang['js']['nosmblinks'] = "Linking to Windows shares only works in Microsoft Internet Explorer.\nYou still can copy and paste the link.";

$lang['qb_bold']    = 'Bold Text';
$lang['qb_italic']  = 'Italic Text';
$lang['qb_underl']  = 'Underlined Text';
$lang['qb_code']    = 'Code Text';
$lang['qb_strike']  = 'Strike-through Text';
$lang['qb_h1']      = 'Level 1 Headline';
$lang['qb_h2']      = 'Level 2 Headline';
$lang['qb_h3']      = 'Level 3 Headline';
$lang['qb_h4']      = 'Level 4 Headline';
$lang['qb_h5']      = 'Level 5 Headline';
$lang['qb_link']    = 'Internal Link';
$lang['qb_extlink'] = 'External Link';
$lang['qb_hr']      = 'Horizontal Rule';
$lang['qb_ol']      = 'Ordered List Item';
$lang['qb_ul']      = 'Unordered List Item';
$lang['qb_media']   = 'Add Images and other files';
$lang['qb_sig']     = 'Insert Signature';

$lang['js']['del_confirm']= 'Delete this entry?';

$lang['admin_acl']  = 'Access Control List Management...';
$lang['admin_register']= 'Add new user...';

$lang['acl_group']  = 'Group';
$lang['acl_user']   = 'User';
$lang['acl_perms']  = 'Permissions for';
$lang['page']       = 'Rûpel';
$lang['namespace']  = 'Namespace';

$lang['acl_perm1']  = 'Bixwîne';
$lang['acl_perm2']  = 'Biguherîne';
$lang['acl_perm4']  = 'Biafirîne';
$lang['acl_perm8']  = 'Upload';
$lang['acl_perm16'] = 'Jê bibe';
$lang['acl_new']    = 'Add new Entry';

$lang['metaedit']    = 'Edit Metadata';
$lang['metasaveerr'] = 'Writing metadata failed';
$lang['metasaveok']  = 'Metadata saved';
$lang['img_backto']  = 'Back to';
$lang['img_title']   = 'Title';
$lang['img_caption'] = 'Caption';
$lang['img_date']    = 'Date';
$lang['img_fname']   = 'Filename';
$lang['img_fsize']   = 'Size';
$lang['img_artist']  = 'Photographer';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Format';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Keywords';

$lang['subscribe_success']  = 'Added %s to subscription list for %s';
$lang['subscribe_error']    = 'Error adding %s to subscription list for %s';
$lang['subscribe_noaddress']= 'There is no address associated with your login, you cannot be added to the subscription list';
$lang['unsubscribe_success']= 'Removed %s from subscription list for %s';
$lang['unsubscribe_error']  = 'Error removing %s from subscription list for %s';

//Setup VIM: ex: et ts=2 :
